<?php

/**
 * Plugin Name: FormToEmail [shortcodes]
 * Plugin URI:  https://formtoemail.com
 * Version:     1.0.1
 * Author:      FormToEmail
 * Author URI:  https://formtoemail.com
 * Description: Create shortcodes for the forms you create in your FromToEmail account.
 * Text Domain: formtoemail
 * Domain Path: /languages
 * Tags: forms, forms to email, embed form, web forms, contact form, email form, formtoemail
 * Requires at least: 2.6
 * Tested up to: 6.4.1
 * Stable tag: 1.0.1
 * License: GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 *
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

add_shortcode('formtoemail', 'formtoemail_shortcode');
function formtoemail_shortcode($atts, $content = '')
{
    extract(shortcode_atts(array(
        'id' => false
    ), $atts));

    if (!isset($id) || !$id)
        return '';

    $snippet = get_option('formtoemail_shortcodes-' . $id);

    return $snippet;
}

add_action('admin_menu', 'formtoemail_admin_menu');
function formtoemail_admin_menu()
{
    add_menu_page('FormToEmail', 'FormToEmail', 'edit_posts', 'formtoemail-shortcodes', 'formtoemail_settings', 'dashicons-feedback');
}

function formtoemail_settings()
{
    // sanitize data
    $edit_id = sanitize_key($_GET['edit']);
    $add = sanitize_key($_GET['add']);
    $rhs_nonce = sanitize_key($_GET['rhs_nonce']);
    $rhs_del = sanitize_key($_GET['rhs_del']);

    if ($edit_id)
        return formtoemail_editor();

    if ($add)
        return formtoemail_add();

    if ($rhs_del && wp_verify_nonce($rhs_nonce, 'rhs_delete')) {
        delete_option('formtoemail_shortcodes-' . $rhs_del);
        $snippet_list = get_option('formtoemail_shortcodes_list');
        if (is_array($snippet_list) && in_array($rhs_del, $snippet_list)) {
            $snippet_list = array_diff($snippet_list, array($rhs_del));
            update_option('formtoemail_shortcodes_list', $snippet_list);
            $success = 'Snippet with ID &quot;' . esc_html($rhs_del) . '&quot; successfully deleted.';
        }
    }


    $snippet_list = get_option('formtoemail_shortcodes_list');
    if (!is_array($snippet_list))
        $snippet_list = array();

    wp_enqueue_style('formtoemail', esc_url(plugins_url('formtoemail.css', __FILE__)));
?>
    <div class="wrap">
        <h1 style="background: #e73254;  background: -moz-linear-gradient(left, #e73254, #ffb65e);  background: -webkit-linear-gradient(left, #e73254, #ffb65e);  background: linear-gradient(left, #e73254, #ffb65e);margin:-10px -20px 20px -22px;padding:28px 22px;color:#fff;">
            <img src="<?php echo esc_url(plugins_url('logo.png', __FILE__)); ?>" alt="FormToEmail" style="width:215px;vertical-align:top;margin-right:1em;"> [shortcodes]
        </h1>
        <h3>Manage your form HTML and shortcodes for use with your <a href="https://formtoemail.com" style="vertical-align:bottom;" target="_blank">FormToEmail Account</a></h3>

        <ul style="list-style:outside;margin-left:20px;">

            <li>Create a unique "Form Name"</li>
            <li>Paste / Edit the form HTML from your <a href="https://formtoemail.com" target="_blank">FormToEmail User
                    Panel</a></li>
            <li>Insert your form to any page using it's shortcode:
                <code>[formtoemail id="my_form_name"]</code>
            </li>
        </ul>
        <p><a href="?page=formtoemail-shortcodes&amp;add=1" class="button-primary">Add a New Form +</a></p>
        <?php if (count($snippet_list) > 0) : ?>

            <table class="widefat striped">
                <thead>
                    <tr>
                        <th>Form Name</th>
                        <th>Shortcode</th>
                    </tr>
                </thead>
                <tbody>

                    <?php foreach ($snippet_list as $snippet_id) : ?>
                        <tr>
                            <td>

                                <strong>
                                    <a href="?page=formtoemail-shortcodes&amp;edit=<?php echo esc_url(rawurlencode($snippet_id)); ?>">
                                        <?php echo esc_html($snippet_id); ?>
                                    </a>
                                </strong>
                                <div class="row-actions">
                                    <a href="?page=formtoemail-shortcodes&amp;edit=<?php echo esc_url(rawurlencode($snippet_id)); ?>">Edit</a>
                                    |
                                    <span class="trash"><a class="submitdelete" onclick="return confirm('Are you sure you want to delete this form\'s HTML permanently?');" href="?page=formtoemail-shortcodes&amp;rhs_nonce=<?php echo esc_attr(wp_create_nonce('rhs_delete')); ?>&amp;rhs_del=<?php echo esc_attr($snippet_id); ?>">Delete</a></span>
                                </div>
                            </td>
                            <td>
                                <code>[formtoemail id="<?php echo esc_html($snippet_id); ?>"]</code>
                            </td>
                        </tr>
                    <?php endforeach; ?>

                </tbody>
            </table>

        <?php else : ?><!-- If no forms -->
            <p class="bounce">&#x2b06;</p>
        <?php endif; ?>
    </div>
<?php
} // end no forms

function formtoemail_editor()
{
    // sanitize data
    $snippet_id = sanitize_key($_GET['edit']);
    $rhs_nonce = sanitize_key($_POST['rhs_nonce']);

    $errors = array();
    if (!empty($_POST) && wp_verify_nonce($rhs_nonce, 'rhs_nonce')) {
        $snippet = sanitize_textarea_field($_POST['snippet_code']);
        if (empty($snippet))
            $errors[] = 'Enter some HTML for this snippet.';
        if (count($errors) <= 0) {
            update_option('formtoemail_shortcodes-' . $snippet_id, $snippet);
            $success = 'Your changes have been saved. Your shortcode is: <code>[formtoemail id="' . esc_html($snippet_id) . '"]</code>';
        }
    }
    $snippet = get_option('formtoemail_shortcodes-' . $snippet_id);
    $clean = array(
        'snippet_code' => $snippet
    );

    wp_enqueue_script('ace', esc_url(plugins_url('ace.js', __FILE__)));
    wp_enqueue_script('aceeditor', esc_url(plugins_url('formtoemail.js', __FILE__)));
?>
    <div class="wrap">
        <h1 style="background: #e73254;  background: -moz-linear-gradient(left, #e73254, #ffb65e);  background: -webkit-linear-gradient(left, #e73254, #ffb65e);  background: linear-gradient(left, #e73254, #ffb65e);margin:-10px -20px 20px -22px;padding:28px 22px;color:#fff;">
            <img src="<?php echo esc_url(plugins_url('logo.png', __FILE__)); ?>" alt="FormToEmail" style="width:215px;vertical-align:top;margin-right:1em;"> [shortcodes]
        </h1>

        <?php if (count($errors) > 0) : ?>
            <div class="message error"><?php echo wpautop(esc_html(implode("\n", $errors))); ?></div>
        <?php endif; ?>
        <?php if (isset($success) && !empty($success)) : ?>
            <div class="message updated"><?php echo wpautop(esc_html($success)); ?></div>
        <?php endif; ?>

        <h3>Edit Form HTML <a class="page-title-action fade-out" href="?page=formtoemail-shortcodes">Back to Form
                List</a></h3>

        <form method="post" action="">


            <?php wp_nonce_field('rhs_nonce', 'rhs_delete'); ?>
            <p>
                Form Name: <code><?php echo esc_html($snippet_id); ?></code></strong>
            </p>
            <p>
                Shortcode: <code>[formtoemail id="<?php echo esc_html($snippet_id); ?>"]</code>
            </p>
            <p><label for="snippet_code">Form HTML Code:</label>
                <textarea dir="ltr" dirname="ltr" id="snippet_code" name="snippet_code" data-editor="html" rows="25" style="font-family:Monaco,'Courier New',Courier,monospace;font-size:12px;width:100%;color:#555;"><?php if (isset($clean['snippet_code'])) echo esc_attr($clean['snippet_code']); ?></textarea>
            </p>
            <p>
                <input type="submit" class="button-primary" value="Save Form HTML" />
                <?php wp_nonce_field('rhs_nonce', 'rhs_nonce'); ?>
            </p>
        </form>
    </div>
<?php
}

function formtoemail_add()
{
    $snippet_list = get_option('formtoemail_shortcodes_list');
    if (!is_array($snippet_list))
        $snippet_list = array();

    $errors = array();
    $clean = array();

    if (!empty($_POST) && wp_verify_nonce(sanitize_key($_POST['rhs_nonce']), 'rhs_nonce')) {

        $clean['snippet_code'] = sanitize_textarea_field($_POST['snippet_code'] ?? '');
        $clean['snippet_id'] = sanitize_text_field($_POST['snippet_id'] ?? '');

        if (empty($clean['snippet_id']))
            $errors[] = 'Please enter a unique Form Name.';
        elseif (in_array(strtolower($clean['snippet_id']), $snippet_list))
            $errors[] = 'You have entered a Form Name that already exists. Names are NOT case-sensitive.';

        if (empty($clean['snippet_code']))
            $errors[] = 'Enter the HTML for this Form.';

        if (count($errors) <= 0) {
            // save snippet
            $snippet_id = strtolower($clean['snippet_id']);
            $snippet_id = str_replace(' ', '_', $snippet_id);
            $snippet_id = preg_replace('/[^A-Za-z0-9\_]/', '', $snippet_id);
            $snippet_list[] = $snippet_id;
            update_option('formtoemail_shortcodes_list', $snippet_list);
            update_option('formtoemail_shortcodes-' . $snippet_id, $clean['snippet_code']);
            $success = 'Your form\'s HTML has been saved successfully.';
            $clean = array();
        }
    }

    wp_enqueue_script('ace', esc_url(plugins_url('ace.js', __FILE__)));
    wp_enqueue_script('aceeditor', esc_url(plugins_url('formtoemail.js', __FILE__)));
?>
    <div class="wrap">
        <h1 style="background: #e73254;  background: -moz-linear-gradient(left, #e73254, #ffb65e);  background: -webkit-linear-gradient(left, #e73254, #ffb65e);  background: linear-gradient(left, #e73254, #ffb65e);margin:-10px -20px 20px -22px;padding:28px 22px;color:#fff;">
            <img src="<?php echo esc_url(plugins_url('logo.png', __FILE__)); ?>" alt="FormToEmail" style="width:215px;vertical-align:top;margin-right:1em;"> [shortcodes]
        </h1>

        <?php if (count($errors) > 0) : ?>
            <div class="message error"><?php echo wpautop(esc_html(implode("\n", $errors))); ?></div>
        <?php endif; ?>
        <?php if ($success) : ?>
            <div class="message updated"><?php echo wpautop(esc_html($success)); ?></div>

            <br>
            <h3>Insert your form to any page using the shortcode: <code>[formtoemail
                    id="<?php echo esc_html($snippet_id) ?>"]</code></h3><br>
            <p><a class="button" href="?page=formtoemail-shortcodes">&laquo; Back to Form List</a> or <a class="button" href="?page=formtoemail-shortcodes&amp;add=1">Add
                    a New Form +</a></p>

        <?php else : ?>


            <h3>New Form Shortcode &amp; HTML <a class="page-title-action fade-out" href="?page=formtoemail-shortcodes">
                    Back to Form List</a></h3>

            <form method="post" action="">

                <?php wp_nonce_field('rhs_nonce', 'rhs_nonce'); ?>

                <p>
                    <label for="snippet_id">Form Name: <span style="color:#999;font-size:.9em;">(doesn't show on website)</span></label>
                    <br />
                    <input type="text" name="snippet_id" id="snippet_id" size="40" value="<?php
                                                                                            if (isset($clean['snippet_id']))
                                                                                                echo esc_attr($clean['snippet_id']);
                                                                                            ?>" />
                </p>

                <p><label for="snippet_code">Form HTML Code:</label><br>
                    <textarea dir="ltr" dirname="ltr" id="snippet_code" name="snippet_code" data-editor="html" rows="25" style="font-family:Monaco,'Courier New',Courier,monospace;font-size:12px;width:100%;color:#555;"><?php if (isset($clean['snippet_code'])) echo esc_attr($clean['snippet_code']); ?></textarea>
                </p>
                <p><input type="submit" class="button-primary" value="Save Form HTML" /></p>
            </form>
        <?php endif; // end no success 
        ?>
    </div>
<?php
}
